aboutsummaryrefslogtreecommitdiffstats
path: root/src/qml/compiler/qv4codegen.cpp
diff options
context:
space:
mode:
authorLars Knoll <lars.knoll@qt.io>2017-08-16 16:30:15 +0200
committerErik Verbruggen <erik.verbruggen@qt.io>2017-08-25 11:59:18 +0000
commit34280d266fe4bed0274b260c0091d50908acd087 (patch)
treec7a757587a33119c293b1c909d228f38f4179347 /src/qml/compiler/qv4codegen.cpp
parent69a1018c9737751c2cc7daae2c03882dc81bd104 (diff)
Cleanup object construction instructions
Remove the unused Create/Construct instructions, and rename the single remaining one to 'Construct'. Change-Id: I10163a15681156f37e34d21a05d195d3c22adcff Reviewed-by: Erik Verbruggen <erik.verbruggen@qt.io>
Diffstat (limited to 'src/qml/compiler/qv4codegen.cpp')
-rw-r--r--src/qml/compiler/qv4codegen.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/qml/compiler/qv4codegen.cpp b/src/qml/compiler/qv4codegen.cpp
index 5a7c12d0a2..0b8091d70e 100644
--- a/src/qml/compiler/qv4codegen.cpp
+++ b/src/qml/compiler/qv4codegen.cpp
@@ -1483,12 +1483,12 @@ bool Codegen::visit(NewExpression *ast)
Reference base = expression(ast->expression);
if (hasError)
return false;
//### Maybe create a CreateValueA that takes an accumulator?
base = base.storeOnStack();
auto calldata = pushArgs(0);
- Instruction::CreateValue create;
+ Instruction::Construct create;
create.func = base.stackSlot();
create.callData = calldata;
bytecodeGenerator->addInstruction(create);
@@ -1512,7 +1512,7 @@ bool Codegen::visit(NewMemberExpression *ast)
if (hasError)
return false;
- Instruction::CreateValue create;
+ Instruction::Construct create;
create.func = base.stackSlot();
create.callData = calldata;
bytecodeGenerator->addInstruction(create);
@@ -1483,12 +1483,12 @@ bool Codegen::visit(NewExpression *ast)
if (hasError)
return false;
- //### Maybe create a CreateValueA that takes an accumulator?
+ //### Maybe create a ConstructA that takes an accumulator?
base = base.storeOnStack();
auto calldata = pushArgs(0);